@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1200';
+our $VERSION = '0.1201';
 
 use Moo;
 use Music::Chord::Note;
@@ -247,7 +247,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1200
+version 0.1201
 
 =head1 SYNOPSIS
 
@@ -310,6 +310,12 @@ version 0.1200
   $chords = $mc->cadence;
   # [['G','B','D','F'], ['C','E','G','A#','C']]
 
+  $chords = $mc->cadence(
+    octave => 4,
+    type   => 'evaded',
+  );
+  # [['F4','G5','B5','D5'], ['E4','G4','A#4','C5']]
+
 =head1 DESCRIPTION
 
 C<Music::Cadence> generates a pair of musical cadence chords.
@@ -401,6 +407,7 @@ on the given B<key> and B<scale> name.
 Supported cadences are:
 
   deceptive
+  evaded
   half
   imperfect
   perfect
@@ -448,6 +455,8 @@ this is:
 If an B<inversion> is defined for the C<half> cadence, the chords are
 inverted as described above for the C<imperfect> cadence.
 
+The B<evaded> cadence applies inversions to seventh chords.
+
 =head1 SEE ALSO
 
 The F<eg/cadence>, F<t/01-methods.t> and F<t/02-methods.t> files in
